@@ -20,16 +20,15 @@
 #define GLGRAPHWIDGETPLUGIN_H
 
 #include <customwidget.h>
-    
+
 namespace tlp {
 
-class GlMainWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
-{
+class GlMainWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface {
   Q_OBJECT
   Q_INTERFACES(QDesignerCustomWidgetInterface)
 public:
   GlMainWidgetPlugin(QObject *parent = 0);
-    
+
   bool isContainer() const;
   bool isInitialized() const;
   QIcon icon() const;
