@@ -29,8 +29,7 @@ namespace tlp {
 class Graph;
 /** \addtogroup Mouse_interactor */
 /*@{*/
-class TLP_QT_SCOPE MouseSelector:public InteractorComponent
-{
+class TLP_QT_SCOPE MouseSelector:public InteractorComponent {
 protected:
   Qt::MouseButton mButton;
   Qt::KeyboardModifier kModifier;
@@ -40,12 +39,23 @@ protected:
   bool started;
   Graph *graph;
 public:
-  MouseSelector(Qt::MouseButton button = Qt::LeftButton,
-		Qt::KeyboardModifier modifier = Qt::NoModifier);
+  MouseSelector(Qt::MouseButton button = Qt::LeftButton, Qt::KeyboardModifier modifier = Qt::NoModifier);
   ~MouseSelector() {}
   bool draw(GlMainWidget *);
   bool eventFilter(QObject *, QEvent *);
-  InteractorComponent *clone() { return new MouseSelector(mButton, kModifier); }
+  InteractorComponent *clone() {
+    return new MouseSelector(mButton, kModifier, _mode);
+  }
+
+  //all of this stands here to keep binary compatibility. here should be only one constructor on the next minor version bump.
+  enum SelectionMode {
+    EdgesAndNodes = 0,
+    EdgesOnly,
+    NodesOnly
+  };
+  MouseSelector(Qt::MouseButton button, Qt::KeyboardModifier modifier, SelectionMode mode);
+protected:
+  SelectionMode _mode;
 };
 /*@}*/
 
