@@ -20,14 +20,13 @@
 #define TULIPPROPERTYTABLEPLUGIN_H
 
 #include <customwidget.h>
-    
-class PropertyWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
-{
+
+class PropertyWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface {
   Q_OBJECT
   Q_INTERFACES(QDesignerCustomWidgetInterface)
 public:
   PropertyWidgetPlugin(QObject *parent = 0);
-    
+
   bool isContainer() const;
   bool isInitialized() const;
   QIcon icon() const;
