@@ -20,20 +20,19 @@
 #ifndef _SELECTIONALGO_H
 #define _SELECTIONALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
 class BooleanProperty;
 
 /**
  * \addtogroup plugins
- */ 
+ */
 /*@{*/
 
 /// Interface for selection plug-ins
-class TLP_SCOPE BooleanAlgorithm:public PropertyAlgorithm { 
+class TLP_SCOPE BooleanAlgorithm : public tlp::Algorithm {
   ///
   friend class BooleanProperty;
 public:
@@ -42,11 +41,11 @@ public:
    **/
   BooleanProperty *booleanResult;
   ///
-  virtual ~BooleanAlgorithm(){}
+  virtual ~BooleanAlgorithm() {}
 
 protected:
   ///
-  BooleanAlgorithm (const PropertyContext &);
+  BooleanAlgorithm (const AlgorithmContext &);
 };
 /*@*/
 
