@@ -20,17 +20,16 @@
 #ifndef TULIP_COLORSALGO_H
 #define TULIP_COLORSALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
 class ColorProperty;
 
-/** \addtogroup plugins */ 
+/** \addtogroup plugins */
 /*@{*/
 /// Interface for color plug-ins
-class TLP_SCOPE ColorAlgorithm:public PropertyAlgorithm { 
+class TLP_SCOPE ColorAlgorithm : public tlp::Algorithm {
   ///
   friend class ColorProperty;
 public:
@@ -40,7 +39,7 @@ public:
 
 protected:
   ///
-  ColorAlgorithm (const PropertyContext & context);
+  ColorAlgorithm (const AlgorithmContext & context);
 };
 /*@}*/
 
