@@ -20,17 +20,16 @@
 #ifndef _METRICALGO_H
 #define _METRICALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
 class DoubleProperty;
 
-/** \addtogroup plugins */ 
+/** \addtogroup plugins */
 /*@{*/
 /// Interface for metric plug-ins
-class TLP_SCOPE DoubleAlgorithm:public PropertyAlgorithm { 
+class TLP_SCOPE DoubleAlgorithm : public tlp::Algorithm {
   ///
   friend class DoubleProperty;
 public:
@@ -42,7 +41,7 @@ public:
 
 protected:
   ///
-  DoubleAlgorithm (const PropertyContext  &context);
+  DoubleAlgorithm (const AlgorithmContext &context);
 };
 /*@}*/
 
