@@ -21,18 +21,17 @@
 #ifndef TULIP_INTALGO_H
 #define TULIP_INTALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
 class IntegerProperty;
 
-/** \addtogroup plugins */ 
+/** \addtogroup plugins */
 /*@{*/
 
 /// Interface for int plug-ins
-class TLP_SCOPE IntegerAlgorithm:public PropertyAlgorithm { 
+class TLP_SCOPE IntegerAlgorithm : public tlp::Algorithm {
   ///
   friend class IntegerProperty;
 public:
@@ -40,11 +39,11 @@ public:
       The data should be store in it*/
   IntegerProperty *integerResult;
   ///
-  virtual ~IntegerAlgorithm(){}
+  virtual ~IntegerAlgorithm() {}
 
 protected:
   ///
-  IntegerAlgorithm (const PropertyContext  &context);
+  IntegerAlgorithm (const AlgorithmContext  &context);
 };
 /*@}*/
 
