@@ -20,23 +20,22 @@
 #ifndef _LAYOUTALGO_H
 #define _LAYOUTALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
 class LayoutProperty;
 
 /**
  * \addtogroup plugins
- */ 
+ */
 /*@{*/
 ///Interface for layout plug-ins
-class TLP_SCOPE LayoutAlgorithm:public PropertyAlgorithm {
+class TLP_SCOPE LayoutAlgorithm : public tlp::Algorithm {
   ///
   friend class LayoutProperty;
 public:
-  /** 
+  /**
    * This layout is the one associated to the plug-ins,
    * The data should be store in it
    */
@@ -44,9 +43,9 @@ public:
   ///
   virtual ~LayoutAlgorithm();
 
-protected: 
+protected:
   ///
-  LayoutAlgorithm (const PropertyContext &context);
+  LayoutAlgorithm (const AlgorithmContext &context);
 };
 /*@}*/
 
