@@ -27,22 +27,24 @@
 namespace tlp {
 
 class TLP_SCOPE PluginLibraryLoader {
- public:
+public:
   int n;
   std::string msg;
   std::string pluginPath;
-  PluginLoader *loader;
+  //PluginLoader *loader;
 
-  PluginLibraryLoader(std::string pluginPath, PluginLoader *loader);
-  bool hasPluginLibraryToLoad() { return n >= 0; }
+  PluginLibraryLoader(const std::string& pluginPath, PluginLoader *loader);
+  bool hasPluginLibraryToLoad() {
+    return n >= 0;
+  }
   bool loadNextPluginLibrary(PluginLoader *loader);
   static bool loadPluginLibrary(const std::string & filename,
-				PluginLoader *loader = 0);
+                                PluginLoader *loader = 0);
   static const std::string& getCurrentPluginFileName() {
     return currentPluginLibrary;
   }
 
- private:
+private:
   void *infos;
   static std::string currentPluginLibrary;
 };
