@@ -20,29 +20,29 @@
 #ifndef TULIP_SIZESALGO_H
 #define TULIP_SIZESALGO_H
 
-#include <tulip/PropertyAlgorithm.h>
+#include <tulip/Algorithm.h>
 
 namespace tlp {
 
-class PropertyContext;
+class AlgorithmContext;
 class SizeProperty;
 
 /**
  * \addtogroup plugins
- */ 
+ */
 /*@{*/
 /// Interface for sizes plug-ins
-class TLP_SCOPE SizeAlgorithm:public PropertyAlgorithm { 
+class TLP_SCOPE SizeAlgorithm : public tlp::Algorithm {
   ///
   friend class SizeProperty;
 public:
   SizeProperty *sizeResult;
   ///
-  virtual ~SizeAlgorithm(){}
+  virtual ~SizeAlgorithm() {}
 
 protected:
   ///
-  SizeAlgorithm (const PropertyContext  &context);
+  SizeAlgorithm (const AlgorithmContext  &context);
 };
 /*@}*/
 
