@@ -33,135 +33,153 @@ const string metaGraphPropertyName = "viewMetaGraph";
 
 //=========================================================================
 GraphAbstract::GraphAbstract(Graph *supergraph, unsigned int sgId)
- :supergraph(supergraph ? supergraph : this),
-  root((supergraph == this) ? this : supergraph->getRoot()),
-  subGraphToKeep(NULL), metaGraphProperty(NULL) {
+  :supergraph(supergraph ? supergraph : this),
+   root((supergraph == this) ? this : supergraph->getRoot()),
+   subGraphToKeep(NULL), metaGraphProperty(NULL) {
   // get id
   if (supergraph != this)
     id = ((GraphImpl *) getRoot())->getSubGraphId(sgId);
+
   propertyContainer = new PropertyManager(this);
 }
 //=========================================================================
 GraphAbstract::~GraphAbstract() {
   StableIterator<Graph *> itS(getSubGraphs());
+
   while(itS.hasNext()) {
     Graph* sg = itS.next();
-    if (id == 0)
-      // indicates root destruction (see below)
-      sg->id = 0;
-    delAllSubGraphsInternal(sg, true);
+
+    // avoid double free
+    // in a push context, a 'deleted' graph (see delSubGraph)
+    // may still have a non empty list of subgraphs
+    if (sg->getSuperGraph() == this) {
+      if (id == 0)
+        // indicates root destruction (see below)
+        sg->id = 0;
+
+      delete sg;
+    }
   }
 
   delete propertyContainer;
-  
+
   if (id != 0)
     ((GraphImpl *) getRoot())->freeSubGraphId(id);
 }
 //=========================================================================
 void GraphAbstract::clear() {
   StableIterator<Graph *> itS(getSubGraphs());
+
   while(itS.hasNext())
     delAllSubGraphs(itS.next());
+
   StableIterator<node> itN(getNodes());
+
   while(itN.hasNext())
     delNode(itN.next());
 }
 //=========================================================================
-void GraphAbstract::restoreSubGraph(Graph* sg, bool undoOrRedo){
+void GraphAbstract::restoreSubGraph(Graph* sg) {
   subgraphs.push_back(sg);
   sg->setSuperGraph(this);
-  if (undoOrRedo) {
-    notifyAddSubGraph(sg);
-    Iterator<Graph *> *itS = sg->getSubGraphs();
-    while (itS->hasNext()) {
-      Graph* ssg = itS->next();
-      // ssg is no longer a subgraph of this
-      removeSubGraph(ssg);
-      ssg->setSuperGraph(sg);
-    } delete itS;
-  }
 }
 //=========================================================================
-void GraphAbstract::setSubGraphToKeep(Graph* sg){
+void GraphAbstract::setSubGraphToKeep(Graph* sg) {
   subGraphToKeep = sg;
 }
 //=========================================================================
-Graph *GraphAbstract::addSubGraph(BooleanProperty *selection, unsigned int id){
+Graph *GraphAbstract::addSubGraph(BooleanProperty *selection, unsigned int id,
+                                  std::string name) {
   Graph *tmp = new GraphView(this, selection, id);
+  tmp->setAttribute("name", name);
   subgraphs.push_back(tmp);
   notifyAddSubGraph(tmp);
   return tmp;
 }
 //=========================================================================
+Graph *GraphAbstract::getNthSubGraph(unsigned int n) const {
+  if (n >= subgraphs.size())
+    return NULL;
+
+  return subgraphs[n];
+}
+//=========================================================================
+unsigned int GraphAbstract::numberOfSubGraphs() const {
+  return subgraphs.size();
+}
+//=========================================================================
+unsigned int GraphAbstract::numberOfDescendantGraphs() const {
+  GRAPH_SEQ::const_iterator it = subgraphs.begin();
+  int result = numberOfSubGraphs();
+
+  while(it != subgraphs.end()) {
+    result += (*it)->numberOfDescendantGraphs();
+    it++;
+  }
+
+  return result;
+}
+//=========================================================================
 void GraphAbstract::delSubGraph(Graph *toRemove) {
   // look for the graph we want to remove in the subgraphs
-  GRAPH_SEQ::iterator it = subgraphs.begin();
-  while (it != subgraphs.end()) {
-    if (*it == toRemove) {
-      break;
-    }
-    ++it;
-  }
+  GRAPH_SEQ::iterator it =
+    std::find(subgraphs.begin(), subgraphs.end(), toRemove);
+
   assert(it != subgraphs.end());
+
   if (it != subgraphs.end()) {
     subGraphToKeep = NULL;
     notifyDelSubGraph(toRemove);
 
-    Iterator<Graph *> *itS = toRemove->getSubGraphs();
     // remove from subgraphs
     subgraphs.erase(it);
+
+    Iterator<Graph *> *itS = toRemove->getSubGraphs();
+
     // add toRemove subgraphs
     while (itS->hasNext()) {
       restoreSubGraph(itS->next());
-    } delete itS;
+    }
+
+    delete itS;
+
+    // subGraphToKeep may have change on notifyDelSubGraph
+    // see GraphUpdatesRecorder::delSubGraph
+    // in GraphUpdatesRecorder.cpp
     if (toRemove != subGraphToKeep) {
       // avoid deletion of toRemove subgraphs
-      ((GraphAbstract *) toRemove)->subgraphs.clear();
+      toRemove->clearSubGraphs();
       delete toRemove;
-    } else
+    }
+    else
       // toRemove is not deleted,
-      // it can be restored on undo or redo
+      // and its subgraphs list is not erased;
+      // beacause it is registered into a GraphUpdatesRecorder
+      // in order it can be restored on undo or redo
       toRemove->notifyDestroy();
   }
 }
 //=========================================================================
-void GraphAbstract::removeSubGraph(Graph * toRemove, bool notify) {
-  for (GRAPH_SEQ::iterator it = subgraphs.begin(); it != subgraphs.end(); ++it) {
-    if (*it == toRemove) {
-      // when called from GraphUpdatesRecorder
-      // we must notify the observers
-      if (notify)
-	notifyDelSubGraph(toRemove);
-      subgraphs.erase(it);
-      if (notify) {
-	toRemove->notifyDestroy();
-      }
-      break;
-    }
-  }
-}
-//=========================================================================
-void GraphAbstract::delAllSubGraphsInternal(Graph * toRemove,
-					    bool deleteSubGraphs) {
-  if (this != toRemove->getSuperGraph() || this==toRemove) // this==toRemove : root graph
-    return;
-  notifyDelSubGraph(toRemove);
-  removeSubGraph(toRemove);
-  if (deleteSubGraphs)
-    delete toRemove;
-  else {
-    StableIterator<Graph *> itS(toRemove->getSubGraphs());
-    while (itS.hasNext())
-      ((GraphAbstract*) toRemove)->delAllSubGraphsInternal(itS.next(),
-							   deleteSubGraphs);
-    toRemove->notifyDestroy();
+void GraphAbstract::removeSubGraph(Graph * toRemove) {
+  GRAPH_SEQ::iterator it =
+    std::find(subgraphs.begin(), subgraphs.end(), toRemove);
+
+  if (it != subgraphs.end()) {
+    subgraphs.erase(it);
   }
 }
 //=========================================================================
 void GraphAbstract::delAllSubGraphs(Graph * toRemove) {
-  // toRemove will be really deleted only if the current
-  // graph state is not redoable
-  delAllSubGraphsInternal(toRemove, !canPopThenUnpop());
+  if (this != toRemove->getSuperGraph() || this==toRemove)
+    // this==toRemove : root graph
+    return;
+
+  StableIterator<Graph *> itS(toRemove->getSubGraphs());
+
+  while (itS.hasNext())
+    ((GraphAbstract*) toRemove)->delAllSubGraphs(itS.next());
+
+  delSubGraph(toRemove);
 }
 //=========================================================================
 void GraphAbstract::clearSubGraphs() {
@@ -185,55 +203,94 @@ Iterator<Graph *> * GraphAbstract::getSubGraphs() const {
 }
 //=========================================================================
 bool GraphAbstract::isSubGraph(const Graph* sg) const {
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-  while(it != subgraphs.end()) {
-    if (*it == sg)
-      return true;
-    it++;
-  }
-  return false;
+  return (std::find(subgraphs.begin(), subgraphs.end(), sg) != subgraphs.end());
 }
 //=========================================================================
 bool GraphAbstract::isDescendantGraph(const Graph* sg) const {
   if (isSubGraph(sg))
     return true;
+
   GRAPH_SEQ::const_iterator it = subgraphs.begin();
+
   while(it != subgraphs.end()) {
     if ((*it)->isDescendantGraph(sg))
       return true;
+
     it++;
   }
+
   return false;
 }
 //=========================================================================
 Graph* GraphAbstract::getSubGraph(unsigned int sgId) const {
   GRAPH_SEQ::const_iterator it = subgraphs.begin();
+
   while(it != subgraphs.end()) {
     if ((*it)->getId() == sgId)
       return *it;
+
     it++;
   }
+
+  return NULL;
+}
+//=========================================================================
+Graph* GraphAbstract::getSubGraph(const std::string &name) const {
+  GRAPH_SEQ::const_iterator it = subgraphs.begin();
+
+  while(it != subgraphs.end()) {
+    if ((*it)->getName() == name)
+      return *it;
+
+    it++;
+  }
+
   return NULL;
 }
 //=========================================================================
 Graph* GraphAbstract::getDescendantGraph(unsigned int sgId) const {
   Graph* sg = getSubGraph(sgId);
+
   if (sg)
     return sg;
+
   GRAPH_SEQ::const_iterator it = subgraphs.begin();
+
   while(it != subgraphs.end()) {
     if ((sg = (*it)->getDescendantGraph(sgId)))
       return sg;
+
     it++;
   }
+
+  return NULL;
+}
+//=========================================================================
+Graph* GraphAbstract::getDescendantGraph(const string &name) const {
+  Graph* sg = getSubGraph(name);
+
+  if (sg)
+    return sg;
+
+  GRAPH_SEQ::const_iterator it = subgraphs.begin();
+
+  while(it != subgraphs.end()) {
+    if ((sg = (*it)->getDescendantGraph(name)))
+      return sg;
+
+    it++;
+  }
+
   return NULL;
 }
 //=========================================================================
 node GraphAbstract::getOneNode() const {
   node result;
   Iterator<node> *it = getNodes();
+
   if (it->hasNext())
     result = it->next();
+
   delete it;
   return result;
 }
@@ -241,8 +298,10 @@ node GraphAbstract::getOneNode() const {
 edge GraphAbstract::getOneEdge() const {
   edge result;
   Iterator<edge> *it=getEdges();
+
   if (it->hasNext())
     result = it->next();
+
   delete it;
   return result;
 }
@@ -251,9 +310,12 @@ node GraphAbstract::getInNode(const node n,unsigned int i)const {
   assert(i<=indeg(n) && i>0);
   Iterator<node>*itN=getInNodes(n);
   node result;
-  for(unsigned int j=i+1;j>1;--j){
+
+  for(unsigned int j=i+1; j>1; --j) {
     result=itN->next();
-  }delete itN;
+  }
+
+  delete itN;
   return result;
 }
 //=========================================================================
@@ -261,44 +323,57 @@ node GraphAbstract::getOutNode(const node n,unsigned int i)const {
   assert(i<=outdeg(n) && i>0);
   Iterator<node>*itN=getOutNodes(n);
   node result;
+
   for(unsigned int j=i+1; j>1; --j) {
     result=itN->next();
-  } delete itN;
+  }
+
+  delete itN;
   return result;
 }
 //=========================================================================
 unsigned int GraphAbstract::deg(const node n) const {
   unsigned int deg=0;
   Iterator<edge> *it=getInOutEdges(n);
+
   while (it->hasNext()) {
     it->next();
     ++deg;
-  } delete it;
+  }
+
+  delete it;
   return deg;
 }
 //=========================================================================
 unsigned int GraphAbstract::indeg(const node n) const {
   unsigned int deg=0;
   Iterator<edge> *it=getInEdges(n);
+
   while (it->hasNext()) {
     it->next();
     ++deg;
-  } delete it;
+  }
+
+  delete it;
   return deg;
 }
 //=========================================================================
 unsigned int GraphAbstract::outdeg(const node n) const {
   unsigned int deg=0;
   Iterator<edge> *it=getOutEdges(n);
+
   while(it->hasNext()) {
     it->next();
     ++deg;
-  } delete it;
+  }
+
+  delete it;
   return deg;
 }
 //=========================================================================
 void GraphAbstract::delNodes(Iterator<node>* itN, bool deleteInAllGraphs) {
   assert(itN != NULL);
+
   while(itN->hasNext()) {
     delNode(itN->next(), deleteInAllGraphs);
   }
@@ -341,38 +416,44 @@ void GraphAbstract::reverse(const edge e) {
 }
 //=========================================================================
 edge GraphAbstract::existEdge(const node n1, const node n2,
-			      bool directed) const {
+                              bool directed) const {
   Iterator<edge> *it;
+
   if (directed)
     it = getOutEdges(n1);
   else
     it = getInOutEdges(n1);
+
   while (it->hasNext()) {
     edge e(it->next());
+
     if (opposite(e, n1) == n2) {
       delete it;
       return e;
     }
-  } delete it;
+  }
+
+  delete it;
   return edge();
 }
 //=========================================================================
 void GraphAbstract::delEdges(Iterator<edge>* itE, bool deleteInAllGraphs) {
   assert(itE != NULL);
+
   while(itE->hasNext()) {
     delEdge(itE->next(), deleteInAllGraphs);
   }
 }
 //=========================================================================
-bool GraphAbstract::existProperty(const std::string &name) {
+bool GraphAbstract::existProperty(const std::string &name) const {
   return propertyContainer->existProperty(name);
 }
 //=========================================================================
-bool GraphAbstract::existLocalProperty(const std::string &name) {
+bool GraphAbstract::existLocalProperty(const std::string &name) const {
   return propertyContainer->existLocalProperty(name);
 }
 //=========================================================================
-PropertyInterface* GraphAbstract::getProperty(const string &str) {
+PropertyInterface* GraphAbstract::getProperty(const string &str) const {
   return propertyContainer->getProperty(str);
 }
 //=========================================================================
@@ -386,9 +467,11 @@ void GraphAbstract::delLocalProperty(const std::string &name) {
 void GraphAbstract::addLocalProperty(const std::string &name, PropertyInterface *prop) {
   assert(!existLocalProperty(name));
   propertyContainer->setLocalProperty(name, prop);
+
   if (name == metaGraphPropertyName) {
     metaGraphProperty = (GraphProperty *) prop;
-  }    
+  }
+
   notifyAddLocalProperty(name);
 }
 //=========================================================================
@@ -397,9 +480,9 @@ void GraphAbstract::notifyAddInheritedProperty(const std::string& name) {
     sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_INHERITED_PROPERTY, name));
 }
 //=========================================================================
-void GraphAbstract::notifyBeforeDelInheritedProperty(const std::string& name){
-    if (hasOnlookers())
-      sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_INHERITED_PROPERTY, name,Event::TLP_INFORMATION));
+void GraphAbstract::notifyBeforeDelInheritedProperty(const std::string& name) {
+  if (hasOnlookers())
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_INHERITED_PROPERTY, name,Event::TLP_INFORMATION));
 }
 //=========================================================================
 void GraphAbstract::notifyAfterDelInheritedProperty(const std::string& name) {
@@ -434,20 +517,26 @@ Iterator<PropertyInterface*>* GraphAbstract::getObjectProperties() const {
 unsigned int GraphAbstract::numberOfNodes() const {
   unsigned int result=0;
   Iterator<node> *it=getNodes();
+
   while(it->hasNext()) {
     it->next();
     result++;
-  } delete it;
+  }
+
+  delete it;
   return result;
 }
 //=========================================================================
 unsigned int GraphAbstract::numberOfEdges() const {
   unsigned int result=0;
   Iterator<edge> *it=getEdges();
+
   while (it->hasNext()) {
     it->next();
     result++;
-  } delete it;
+  }
+
+  delete it;
   return result;
 }
 //=========================================================================
@@ -468,6 +557,7 @@ bool GraphAbstract::isMetaEdge(const edge e) const {
 Graph* GraphAbstract::getNodeMetaInfo(const node n) const {
   if (metaGraphProperty)
     return metaGraphProperty->getNodeValue(n);
+
   return NULL;
 }
 
@@ -507,6 +597,17 @@ Iterator<edge>* GraphAbstract::getEdgeMetaInfo(const edge e) const {
 GraphProperty* GraphAbstract::getMetaGraphProperty() {
   if (metaGraphProperty)
     return metaGraphProperty;
+
   return metaGraphProperty =
-    getRoot()->getProperty<GraphProperty>(metaGraphPropertyName);
+           getRoot()->getProperty<GraphProperty>(metaGraphPropertyName);
+}
+
+void GraphAbstract::setName(const std::string &name) {
+  setAttribute("name", name);
+}
+
+std::string GraphAbstract::getName() const {
+  std::string name;
+  getAttribute("name", name);
+  return name;
 }
