@@ -21,41 +21,49 @@
 using namespace tlp;
 
 //============================================================
-void GraphDecorator::clear(){
+void GraphDecorator::clear() {
   graph_component->clear();
 }
 
 //============================================================
 Graph *GraphDecorator::addSubGraph(BooleanProperty *selection,
-				   unsigned int id){
-  Graph* sg = graph_component->addSubGraph(selection, id);
+                                   unsigned int id,
+                                   std::string name) {
+  Graph* sg = graph_component->addSubGraph(selection, id, name);
   notifyAddSubGraph(sg);
   return sg;
 }
 
 //============================================================
-void GraphDecorator::delSubGraph(Graph *s){
+void GraphDecorator::delSubGraph(Graph *s) {
   notifyDelSubGraph(s);
   graph_component->delSubGraph(s);
 }
-
 //============================================================
-void GraphDecorator::restoreSubGraph(Graph *, bool){
+unsigned int GraphDecorator::numberOfSubGraphs() const {
+  return graph_component->numberOfSubGraphs();
+}
+//============================================================
+unsigned int GraphDecorator::numberOfDescendantGraphs() const {
+  return graph_component->numberOfDescendantGraphs();
+}
+//============================================================
+void GraphDecorator::restoreSubGraph(Graph *) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::setSubGraphToKeep(Graph *){
+void GraphDecorator::setSubGraphToKeep(Graph *) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::removeSubGraph(Graph*, bool){
+void GraphDecorator::removeSubGraph(Graph*) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::clearSubGraphs(){
+void GraphDecorator::clearSubGraphs() {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
@@ -66,22 +74,22 @@ void GraphDecorator::delAllSubGraphs(Graph *s) {
 }
 
 //============================================================
-Graph* GraphDecorator::getSuperGraph()const{
+Graph* GraphDecorator::getSuperGraph()const {
   return graph_component->getSuperGraph();
 }
 
 //============================================================
-void GraphDecorator::setSuperGraph(Graph* s){
+void GraphDecorator::setSuperGraph(Graph* s) {
   graph_component->setSuperGraph(s);
 }
 
 //============================================================
-Graph* GraphDecorator::getRoot() const{
+Graph* GraphDecorator::getRoot() const {
   return graph_component->getRoot();
 }
 
 //============================================================
-Iterator<Graph *> * GraphDecorator::getSubGraphs() const{
+Iterator<Graph *> * GraphDecorator::getSubGraphs() const {
   return graph_component->getSubGraphs();
 }
 
@@ -98,12 +106,19 @@ Graph* GraphDecorator::getSubGraph(unsigned int sgId) const {
   return graph_component->getSubGraph(sgId);
 }
 //=========================================================================
+Graph* GraphDecorator::getSubGraph(const std::string &name) const {
+  return graph_component->getSubGraph(name);
+}
+//=========================================================================
 Graph* GraphDecorator::getDescendantGraph(unsigned int sgId) const {
   return graph_component->getDescendantGraph(sgId);
 }
-
+//=========================================================================
+Graph* GraphDecorator::getDescendantGraph(const std::string &name) const {
+  return graph_component->getDescendantGraph(name);
+}
 //============================================================
-node GraphDecorator::source(const edge e)const{
+node GraphDecorator::source(const edge e)const {
   return graph_component->source(e);
 }
 
@@ -129,7 +144,7 @@ node GraphDecorator::opposite(const edge e, const node n)const {
 
 //============================================================
 edge GraphDecorator::existEdge(const node n, const node m,
-			       bool directed) const {
+                               bool directed) const {
   return graph_component->existEdge(n, m, directed);
 }
 
@@ -144,7 +159,7 @@ void GraphDecorator::setEnds(const edge e, const node src, const node tgt) {
 }
 
 //============================================================
-void GraphDecorator::reverse(const edge e){
+void GraphDecorator::reverse(const edge e) {
   notifyReverseEdge(e);
   graph_component->reverse(e);
 }
@@ -170,26 +185,26 @@ Graph* GraphDecorator::getNodeMetaInfo(const node n)const {
 }
 
 //============================================================
-node GraphDecorator::getOneNode() const{
+node GraphDecorator::getOneNode() const {
   return graph_component->getOneNode();
 }
 
 //============================================================
-node GraphDecorator::getInNode(const node n,unsigned int i)const{
+node GraphDecorator::getInNode(const node n,unsigned int i)const {
   return graph_component->getInNode(n,i);
 }
 
 //============================================================
-node GraphDecorator::getOutNode(const node n,unsigned int i) const{
+node GraphDecorator::getOutNode(const node n,unsigned int i) const {
   return graph_component->getOutNode(n,i);
 }
 
-edge GraphDecorator::getOneEdge() const{
+edge GraphDecorator::getOneEdge() const {
   return graph_component->getOneEdge();
 }
 
 //============================================================
-unsigned int GraphDecorator::numberOfNodes()const{
+unsigned int GraphDecorator::numberOfNodes()const {
   return graph_component->numberOfNodes();
 }
 
@@ -199,7 +214,7 @@ void GraphDecorator::reserveNodes(unsigned int nbNodes) {
 }
 
 //============================================================
-unsigned int GraphDecorator::numberOfEdges()const{
+unsigned int GraphDecorator::numberOfEdges()const {
   return graph_component->numberOfEdges();
 }
 
@@ -209,27 +224,27 @@ void GraphDecorator::reserveEdges(unsigned int nbEdges) {
 }
 
 //============================================================
-bool GraphDecorator::isElement(const node n) const{
+bool GraphDecorator::isElement(const node n) const {
   return graph_component->isElement(n);
 }
 
 //============================================================
-bool GraphDecorator::isMetaNode(const node n) const{
+bool GraphDecorator::isMetaNode(const node n) const {
   return graph_component->isMetaNode(n);
 }
 
 //============================================================
-bool GraphDecorator::isElement(const edge e) const{
+bool GraphDecorator::isElement(const edge e) const {
   return graph_component->isElement(e);
 }
 
 //============================================================
-bool GraphDecorator::isMetaEdge(const edge e) const{
+bool GraphDecorator::isMetaEdge(const edge e) const {
   return graph_component->isMetaEdge(e);
 }
 
 //============================================================
-node GraphDecorator::addNode(){
+node GraphDecorator::addNode() {
   node newNode = graph_component->addNode();
   notifyAddNode(newNode);
   return newNode;
@@ -238,12 +253,13 @@ node GraphDecorator::addNode(){
 //============================================================
 void GraphDecorator::addNodes(unsigned int nb, std::vector<node>& addedNodes) {
   graph_component->addNodes(nb, addedNodes);
+
   if (hasOnlookers())
     sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, addedNodes));
 }
 
 //============================================================
-void GraphDecorator::addNode(const node){
+void GraphDecorator::addNode(const node) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
@@ -253,7 +269,7 @@ void GraphDecorator::addNodes(Iterator<node>*) {
 }
 
 //============================================================
-node GraphDecorator::restoreNode(node n){
+node GraphDecorator::restoreNode(node n) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
   return n;
 }
@@ -264,12 +280,12 @@ void GraphDecorator::restoreNodes(const std::vector<node>&) {
 }
 
 //============================================================
-void GraphDecorator::removeNode(const node){
+void GraphDecorator::removeNode(const node) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-edge GraphDecorator::addEdge(const node n, const node n2){
+edge GraphDecorator::addEdge(const node n, const node n2) {
   edge newEdge = graph_component->addEdge(n, n2);
   notifyAddEdge(newEdge);
   return newEdge;
@@ -277,14 +293,15 @@ edge GraphDecorator::addEdge(const node n, const node n2){
 
 //============================================================
 void GraphDecorator::addEdges(const std::vector<std::pair<node, node> >& edges,
-			      std::vector<edge>& addedEdges) {
+                              std::vector<edge>& addedEdges) {
   graph_component->addEdges(edges, addedEdges);
+
   if (hasOnlookers())
     sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, addedEdges));
 }
 
 //============================================================
-void GraphDecorator::addEdge(const edge){
+void GraphDecorator::addEdge(const edge) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
@@ -294,42 +311,38 @@ void GraphDecorator::addEdges(Iterator<edge>*) {
 }
 
 //============================================================
-edge GraphDecorator::restoreEdge(edge e, node, node){
+edge GraphDecorator::restoreEdge(edge e, node, node) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
   return e;
 }
 
 //============================================================
 void GraphDecorator::restoreEdges(const std::vector<edge>&,
-				  const std::vector<std::pair<node, node> >&) {
+                                  const std::vector<std::pair<node, node> >&) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 //============================================================
-void GraphDecorator::removeEdge(const edge){
+void GraphDecorator::removeEdge(const edge) {
   std::cerr << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::delNode(const node n, bool deleteInAllGraphs){
+void GraphDecorator::delNode(const node n, bool deleteInAllGraphs) {
   notifyDelNode(n);
   graph_component->delNode(n, deleteInAllGraphs);
 }
 
 //============================================================
-void GraphDecorator::delNodes(Iterator<node>* itN, bool deleteInAllGraphs){
+void GraphDecorator::delNodes(Iterator<node>* itN, bool deleteInAllGraphs) {
   assert(itN != NULL);
+
   while(itN->hasNext()) {
     delNode(itN->next(), deleteInAllGraphs);
   }
 }
 
-//============================================================ 
-void GraphDecorator::delAllNode(const node n){
-  delNode(n, true);
-}
-
 //============================================================
-void GraphDecorator::delEdge(const edge e, bool deleteInAllGraphs){
+void GraphDecorator::delEdge(const edge e, bool deleteInAllGraphs) {
   notifyDelEdge(e);
   graph_component->delEdge(e, deleteInAllGraphs);
 }
@@ -337,24 +350,20 @@ void GraphDecorator::delEdge(const edge e, bool deleteInAllGraphs){
 //=========================================================================
 void GraphDecorator::delEdges(Iterator<edge>* itE, bool deleteInAllGraphs) {
   assert(itE != NULL);
+
   while(itE->hasNext()) {
     delEdge(itE->next(), deleteInAllGraphs);
   }
 }
 
 //============================================================
-void GraphDecorator::delAllEdge(const edge e){
-  delEdge(e, true);
-}
-
-//============================================================
-void GraphDecorator::setEdgeOrder(const node n,const std::vector<edge> & s){
+void GraphDecorator::setEdgeOrder(const node n,const std::vector<edge> & s) {
   graph_component->setEdgeOrder(n,s);
 }
 
-void GraphDecorator::swapEdgeOrder(const node n ,const edge e1, const edge e2){
+void GraphDecorator::swapEdgeOrder(const node n ,const edge e1, const edge e2) {
   graph_component->swapEdgeOrder(n, e1, e2);
-} 
+}
 
 //============================================================
 Iterator<node>* GraphDecorator::getNodes() const {
@@ -402,26 +411,26 @@ Iterator<edge>* GraphDecorator::getEdgeMetaInfo(const edge e) const {
 }
 
 //============================================================
-DataSet& GraphDecorator::getNonConstAttributes(){
+DataSet& GraphDecorator::getNonConstAttributes() {
   return graph_component->getNonConstAttributes();
 }
 //============================================================
-PropertyInterface* GraphDecorator::getProperty(const std::string &name){
+PropertyInterface* GraphDecorator::getProperty(const std::string &name) const {
   return graph_component->getProperty(name);
 }
 
-//============================================================ 
-bool GraphDecorator::existProperty(const std::string&name){
+//============================================================
+bool GraphDecorator::existProperty(const std::string&name) const {
   return graph_component->existProperty(name);
 }
 
 //============================================================
-bool GraphDecorator::existLocalProperty(const std::string&name){
+bool GraphDecorator::existLocalProperty(const std::string&name) const {
   return graph_component->existLocalProperty(name) ;
 }
 
 //============================================================
-void GraphDecorator::delLocalProperty(const std::string&name){
+void GraphDecorator::delLocalProperty(const std::string&name) {
   notifyBeforeDelLocalProperty(name);
   graph_component->delLocalProperty(name);
   notifyAfterDelLocalProperty(name);
@@ -472,18 +481,23 @@ bool GraphDecorator::canPopThenUnpop() {
   return graph_component->canPopThenUnpop();
 }
 //----------------------------------------------------------------
-void GraphDecorator::push(bool unpopAllowed) {
-  return graph_component->push(unpopAllowed);
+void GraphDecorator::push(bool unpopAllowed,
+                          std::vector<PropertyInterface*>* propertiesToPreserveOnPop) {
+  return graph_component->push(unpopAllowed, propertiesToPreserveOnPop);
 }
 //----------------------------------------------------------------
 void GraphDecorator::pop(bool unpopAllowed) {
   return graph_component->pop(unpopAllowed);
 }
 //----------------------------------------------------------------
-bool GraphDecorator::nextPopKeepPropertyUpdates(PropertyInterface* prop) {
-  return graph_component->nextPopKeepPropertyUpdates(prop);
-}
-//----------------------------------------------------------------
 void GraphDecorator::unpop() {
   return graph_component->unpop();
 }
+
+void GraphDecorator::setName(const std::string &name) {
+  graph_component->setName(name);
+}
+
+std::string GraphDecorator::getName() const {
+  return graph_component->getName();
+}
