@@ -31,31 +31,36 @@ using namespace tlp;
 bool PlanarityTestImpl::listEdgesUpwardT0(node n1, node n2) {
   if (n1 == n2)
     return true;
+
   node u = n1;
+
   while (u != NULL_NODE && u != n2) {
     edge e = T0EdgeIn.get(u.id);
     obstructionEdges.push_back(e);
     u = p0.get(u.id);
   }
+
   return (u == n2);
 }
 //=================================================================
-/* 
+/*
  * Adds boundary cycle of "cnode" to "list_edges".
  * Precondition:
  * - embed_list[cnode] is an embedding of the 2-connected component represented
  *   by "cnode" with "RBC[cnode] contained in the boundary".
  */
-void PlanarityTestImpl::extractBoundaryCycle(Graph *sG, node cNode, 
-					 list<edge>& listEdges) {
+void PlanarityTestImpl::extractBoundaryCycle(Graph *sG, node cNode,
+    list<edge>& listEdges) {
   assert(embedList[cNode].size()!=0);
   map<node, list<edge> > el;
   BmdListIt<edge> it(embedList[cNode]);
+
   while (it.hasNext()) {
     edge e = it.next();
     node u = sG->source(e);
     el[u].push_back(e);
   }
+
   edge e;
   node u;
   u = parent.get(cNode.id);
@@ -66,6 +71,7 @@ void PlanarityTestImpl::extractBoundaryCycle(Graph *sG, node cNode,
 #ifndef NDEBUG
   unsigned int count = 0;
 #endif
+
   while (u != parent.get(cNode.id)) {
     assert(++count <= numberOfNodesInG);
     e = el[u].front();
@@ -76,10 +82,12 @@ void PlanarityTestImpl::extractBoundaryCycle(Graph *sG, node cNode,
 //=================================================================
 void PlanarityTestImpl::obstrEdgesTerminal(Graph* G, node w, node t, node u) {
   (void)u; //fixes unused parameter warning in release builds
+#ifndef NDEBUG
   node mm = lcaBetween(nodeLabelB.get(t.id), neighborWTerminal.get(t.id), p0);
   assert((listEdgesUpwardT0(nodeLabelB.get(t.id), mm)));
   assert(listEdgesUpwardT0(neighborWTerminal.get(t.id), mm));
   assert(listEdgesUpwardT0(mm, u));
+#endif
   edge e = G->existEdge(nodeLabelB.get(t.id), nodeWithDfsPos.get(labelB.get(t.id)));
   assert(e.isValid());
   obstructionEdges.push_back(e);
@@ -92,29 +100,35 @@ void PlanarityTestImpl::obstrEdgesTerminal(Graph* G, node w, node t, node u) {
  * Adds part of the boundary cycle of "cnode" that contains w1 and doesn't contain
  * path between w2 and w3 to "el".
  */
-void PlanarityTestImpl::addPartOfBc(Graph *sG, node cNode, 
-				node n1, node n2, node n3) {
+void PlanarityTestImpl::addPartOfBc(Graph *sG, node cNode,
+                                    node n1, node n2, node n3) {
   list<edge> bc, el1, el2;
   extractBoundaryCycle(sG, cNode, bc);
   edge e;
   bool flag = false;
   int side = 0;
+
   for (list<edge>::const_iterator it = bc.begin() ; it != bc.end() ; ++it) {
     node source = sG->source(*it);
+
     if (source == n1) {
       if (flag)
-	side = 1;
+        side = 1;
       else
-	side = 2;
+        side = 2;
     }
+
     if (source == n2 || source == n3)
       flag = !flag;
+
     if (flag)
       el1.push_back(e);
     else
       el2.push_back(e);
   }
+
   assert(side!=0);
+
   if (side == 1) {
     el1.splice(el1.begin(), obstructionEdges);
     obstructionEdges = el1;
@@ -128,8 +142,10 @@ void PlanarityTestImpl::addPartOfBc(Graph *sG, node cNode,
 void PlanarityTestImpl::sortByLabelB(node &n1, node &n2, node &n3) {
   if (labelB.get(n2.id) < labelB.get(n1.id))
     swapNode(n1, n2);
+
   if (labelB.get(n3.id) < labelB.get(n1.id))
     swapNode(n1, n3);
+
   if (labelB.get(n3.id) < labelB.get(n2.id))
     swapNode(n2, n3);
 }
@@ -143,23 +159,28 @@ void PlanarityTestImpl::obstrEdgesPNode(Graph *sG, node p, node u) {
 }
 //=================================================================
 void PlanarityTestImpl::calcInfo3Terminals(node &t1, node &t2, node &t3,
-				       int &countMin, int &countF,
-				       node &cNode, node &q) {
+    int &countMin, int &countF,
+    node &cNode, node &q) {
   countMin = countF = 0;
   int min = labelB.get(t1.id);
   min = std::min(min, labelB.get(t2.id));
   min = std::min(min, labelB.get(t3.id));
-  
+
   if (min == labelB.get(t1.id)) countMin++;
+
   if (min == labelB.get(t2.id)) countMin++;
+
   if (min == labelB.get(t3.id)) countMin++;
-  
+
   cNode = q = NULL_NODE;
-  node w1 = t1, w2 = t2, w3 = t3; 
+  node w1 = t1, w2 = t2, w3 = t3;
+
   if (isCNode(t1))
     w1 = parent.get(t1.id);
+
   if (isCNode(t2))
     w2 = parent.get(t2.id);
+
   if (isCNode(t3))
     w3 = parent.get(t3.id);
 
@@ -168,18 +189,26 @@ void PlanarityTestImpl::calcInfo3Terminals(node &t1, node &t2, node &t3,
   node m1 = lcaBetween(w1, w2, parent);
   node m2 = lcaBetween(w1, w3, parent);
   node m3 = lcaBetween(w2, w3, parent);
+
   if (isCNode(m1)) m1 = activeCNodeOf(true, m1);
+
   if (isCNode(m2)) m2 = activeCNodeOf(true, m2);
+
   if (isCNode(m3)) m3 = activeCNodeOf(true, m3);
+
   if (isCNode(m1) && m1 == m2 && m2 == m3) {
     cNode = m1;
     node u1 = lastPNode(w1, cNode);
     node u2 = lastPNode(w2, cNode);
     node u3 = lastPNode(w3, cNode);
+
     if (u1 == t1) countF++;
+
     if (u2 == t2) countF++;
+
     if (u3 == t3) countF++;
   }
+
   if (countF == 3)
     return;
   else
@@ -190,21 +219,25 @@ void PlanarityTestImpl::calcInfo3Terminals(node &t1, node &t2, node &t3,
   node q3 = lcaBetween(w2, w3, p0);
   node k1 = t1, k2 = t2, k3 = t3;
   min = dfsPosNum.get(q1.id);
+
   if (dfsPosNum.get(q2.id) < min) {
     swapNode(k2, k3);
     min = dfsPosNum.get(q2.id);
   }
+
   if (dfsPosNum.get(q3.id) < min) {
     k1 = t3;
     k2 = t2;
     k3 = t1;
     min = dfsPosNum.get(q3.id);
   }
+
   // is min a terminal node?
   if (min == dfsPosNum.get(t1.id) || min == dfsPosNum.get(t2.id) || min == dfsPosNum.get(t3.id)) {
     if (dfsPosNum.get(k2.id) == min) swapNode(k1, k2);
+
     if (dfsPosNum.get(k3.id) == min) swapNode(k1, k3);
-    
+
     assert(dfsPosNum.get(k1.id)==min);
     cNode = activeCNodeOf(true, k1); // dfspos_num[k1] == min;
     int max = dfsPosNum.get(q1.id);
@@ -213,13 +246,13 @@ void PlanarityTestImpl::calcInfo3Terminals(node &t1, node &t2, node &t3,
 
     if (max >= dfsPosNum.get(parent.get(cNode.id).id))
       q = parent.get(cNode.id);
-    else 
-      if (activeCNodeOf(true, k2) != cNode) {
-	q = lastPNode(k2, cNode);
-	swapNode(k2, k3);
-      }
-      else 
-	q = lastPNode(k3, cNode);
+    else if (activeCNodeOf(true, k2) != cNode) {
+      q = lastPNode(k2, cNode);
+      swapNode(k2, k3);
+    }
+    else
+      q = lastPNode(k3, cNode);
+
     t1 = k1;
     t2 = k2;
     t3 = k3;
@@ -235,8 +268,9 @@ void PlanarityTestImpl::calcInfo3Terminals(node &t1, node &t2, node &t3,
  * - if parent_cnode != nil then t3 == nil.
  */
 void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
-				       node t2, node t3, node v) {
+    node t2, node t3, node v) {
   if (t3 == NULL_NODE) t3 = v;
+
   node w1 = t1, w2 = t2, w3 = t3;
   sortByLabelB(w1, w2, w3);
   assert (listEdgesUpwardT0(nodeWithDfsPos.get(labelB.get(w1.id)), nodeWithDfsPos.get(labelB.get(w3.id))));
@@ -244,17 +278,23 @@ void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
   w1 = t1;
   w2 = t2;
   w3 = t3;
+
   if (isCNode(w1)) w1 = parent.get(w1.id);
+
   if (isCNode(w2)) w2 = parent.get(w2.id);
+
   if (isCNode(w3)) w3 = parent.get(w3.id);
+
   node m1 = lcaBetween(w1, w2, p0);
   node m2 = lcaBetween(w1, w3, p0);
   node m3 = lcaBetween(w2, w3, p0);
   int min = dfsPosNum.get(m1.id), max = dfsPosNum.get(m1.id);
+
   if (dfsPosNum.get(m2.id) < min) {
     swapNode(t2, t3);
     min = dfsPosNum.get(m2.id);
   }
+
   if (dfsPosNum.get(m3.id) < min) {
     node k1 = t2, k2 = t3, k3 = t1;
     t1 = k1;
@@ -262,9 +302,10 @@ void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
     t3 = k3;
     min = dfsPosNum.get(m3.id);
   }
+
   //  if (dfsPosNum.get(m2.id) > max) max = dfsPosNum.get(m2.id);
   //  if (dfsPosNum.get(m3.id) > max) max = dfsPosNum.get(m3.id);
-  
+
   max = std::max(max, dfsPosNum.get(m2.id));
   max = std::max(max, dfsPosNum.get(m3.id));
 
@@ -274,6 +315,7 @@ void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
     obstrEdgesTerminal(sG, w, t3, nodeWithDfsPos.get(max));
   else {
     node u = w;
+
     if (lcaBetween(v, nodeWithDfsPos.get(min), p0) == nodeWithDfsPos.get(min)) {
       // v is in the same c-node of node_with_dfspos[min];
       node cNode = activeCNodeOf(true, v);
@@ -281,8 +323,10 @@ void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
       u = v; //last_pnode(node_label_b[v], cnode);
       assert(listEdgesUpwardT0(parent.get(cNode.id), w));
     }
+
     obstrEdgesPNode(sG, v, u);
   }
+
   obstrEdgesTerminal(sG, w, t2, nodeWithDfsPos.get(min));
 }
 // //=================================================================
@@ -295,8 +339,9 @@ void PlanarityTestImpl::obstructionEdgesT0(Graph *sG, node w, node t1,
 //  * - cnode is part of a K_{3,3} obstruction.
 //  */
 void PlanarityTestImpl::obstructionEdgesCountMin1(Graph *sG, node n, node cNode,
-					      node t1, node t2, node t3) {
+    node t1, node t2, node t3) {
   if (t3 == NULL_NODE) t3 = parent.get(cNode.id);
+
   sortByLabelB(t1, t2, t3);
   assert(listEdgesUpwardT0(n, nodeWithDfsPos.get(labelB.get(t3.id))));
   addPartOfBc(sG, cNode, t1, t2, t3);
@@ -328,21 +373,24 @@ void PlanarityTestImpl::obstructionEdgesCountMin1(Graph *sG, node n, node cNode,
 //  * - cnode is part of a K_{3,3} obstruction.
 //  */
 void PlanarityTestImpl::obstructionEdgesCountMin23(Graph *sG,
-					       node n,
-					       node cNode,
-					       node t1,
-					       node t2,
-					       node t3,
-					       node q,
-					       node v) {
+    node n,
+    node cNode,
+    node t1,
+    node t2,
+    node t3,
+    node q,
+    node v) {
   node n1 = t1, n2 = t2, n3 = t3;
+
   if (t3 == NULL_NODE)
     n3 = v;
+
   sortByLabelB(n1, n2, n3);
 
   assert(listEdgesUpwardT0(nodeWithDfsPos.get(labelB.get(n1.id)), nodeWithDfsPos.get(labelB.get(n3.id))));
 
   n2 = lastPNode(t2, cNode);
+
   if (n2 != q)
     addPartOfBc(sG, cNode, q, t1, n2);
   else
@@ -358,9 +406,11 @@ void PlanarityTestImpl::obstructionEdgesCountMin23(Graph *sG,
     assert(listEdgesUpwardT0(q, u));
   }
   else {
-      obstrEdgesPNode(sG, v, n);
-      node mm = lcaBetween(v, parent.get(cNode.id), p0);
-      assert(listEdgesUpwardT0(parent.get(cNode.id), mm));
+    obstrEdgesPNode(sG, v, n);
+#ifndef NDEBUG
+    node mm = lcaBetween(v, parent.get(cNode.id), p0);
+#endif
+    assert(listEdgesUpwardT0(parent.get(cNode.id), mm));
   }
 }
 // //=================================================================
@@ -385,13 +435,14 @@ void PlanarityTestImpl::obstructionEdgesCountMin23(Graph *sG,
 //  * - cnode is part of a K_5 obstruction.
 // */
 void PlanarityTestImpl::obstructionEdgesK5(Graph *sG,
-				       node w,
-				       node cNode,
-				       node t1,
-				       node t2,
-				       node t3) {
+    node w,
+    node cNode,
+    node t1,
+    node t2,
+    node t3) {
   if (t3 == NULL_NODE)
     t3 = parent.get(cNode.id);
+
   int max = labelB.get(t1.id);
   max = std::max(max, labelB.get(t2.id));
   max = std::max(max, labelB.get(t3.id));
@@ -403,6 +454,7 @@ void PlanarityTestImpl::obstructionEdgesK5(Graph *sG,
   extractBoundaryCycle(sG, cNode, obstructionEdges);
   obstrEdgesTerminal(sG, w, t1, t1);
   obstrEdgesTerminal(sG, w, t2, t2);
+
   if (t3 != parent.get(cNode.id))
     obstrEdgesTerminal(sG, w, t3, t3);
   else
@@ -410,9 +462,9 @@ void PlanarityTestImpl::obstructionEdgesK5(Graph *sG,
 }
 // //=================================================================
 void PlanarityTestImpl::obstructionEdgesPossibleObstrConfirmed(Graph *sG,
-							   node w,
-							   node t,
-							   node v) {
+    node w,
+    node t,
+    node v) {
   node cNode = cNodeOfPossibleK33Obstruction;
   node f = obstructionNodes.front();
   obstructionNodes.pop_front();
@@ -423,19 +475,24 @@ void PlanarityTestImpl::obstructionEdgesPossibleObstrConfirmed(Graph *sG,
 
   if (labelB.get(jl.id) > dfsPosNum.get(w.id))
     nodeLabelB.set(jl.id, neighborWTerminal.get(t.id));
+
   if (labelB.get(jr.id) > dfsPosNum.get(w.id))
     nodeLabelB.set(jr.id, neighborWTerminal.get(t.id));
+
   node w1 = nodeWithDfsPos.get(labelB.get(v.id));
   node w2 = nodeWithDfsPos.get(labelB.get(f.id));
+
   if (dfsPosNum.get(w2.id) < dfsPosNum.get(w1.id))
     swapNode(w1, w2);
+
   assert(listEdgesUpwardT0(w, w2));
   assert(listEdgesUpwardT0(nodeLabelB.get(f.id), f));
   assert(listEdgesUpwardT0(nodeLabelB.get(jl.id), jl));
   assert(listEdgesUpwardT0(nodeLabelB.get(jr.id), jr));
 
+#ifndef NDEBUG
   node m = lcaBetween(parent.get(cNode.id), v, p0);
-
+#endif
   assert(listEdgesUpwardT0(parent.get(cNode.id), m));
   assert(listEdgesUpwardT0(nodeLabelB.get(v.id), m));
 
@@ -466,20 +523,24 @@ void PlanarityTestImpl::obstructionEdgesPossibleObstrConfirmed(Graph *sG,
  * of cnode.
  */
 void PlanarityTestImpl::obstructionEdgesCNodeCounter(Graph *sG, node cNode, node w,
-						 node jl, node jr, node t1, node t2) {
+    node jl, node jr, node t1, node t2) {
   //  cout << __PRETTY_FUNCTION__ << endl;
   // seachs for a node f in RBC[cNode] between jl and jr s.t.
   // f has a descendant that is a neighbor of w in G;
   bool flag = false;
-  node v = NULL_NODE, f = NULL_NODE, t12 = NULL_NODE, t22 = NULL_NODE;
+  node f = NULL_NODE, t12 = NULL_NODE, t22 = NULL_NODE;
+
   if (t1 != NULL_NODE && t1 != cNode)
     t12 = lastPNode(t1, cNode);
+
   if (t2 != NULL_NODE && t2 != cNode)
     t22 = lastPNode(t2, cNode);
-  
+
   BmdListIt<node> it(RBC[cNode]);
+
   while (it.hasNext()) {
     node v = it.next();
+
     if (v == jl || v == jr)
       flag = true;
     else if (flag && (v == t12 || v == t22 || labelB.get(v.id) == dfsPosNum.get(w.id))) {
@@ -487,11 +548,12 @@ void PlanarityTestImpl::obstructionEdgesCNodeCounter(Graph *sG, node cNode, node
       break;
     }
   }
+
   if (f == t12)
     nodeLabelB.set(f.id, neighborWTerminal.get(t1.id));
   else if (f == t22)
     nodeLabelB.set(f.id, neighborWTerminal.get(t2.id));
-  
+
   //#ifdef _DEBUG_MODE_
   // if (f == NULL_NODE) {
   //     cout << "-> Program terminated! (obstruction_edges_cnode_counter-01)";
@@ -505,8 +567,10 @@ void PlanarityTestImpl::obstructionEdgesCNodeCounter(Graph *sG, node cNode, node
 
   node w1 = nodeWithDfsPos.get(labelB.get(jl.id));
   node w2 = nodeWithDfsPos.get(labelB.get(jr.id));
+
   if (dfsPosNum.get(w2.id) < dfsPosNum.get(w1.id))
     swapNode(w1, w2);
+
   assert(listEdgesUpwardT0(parent.get(cNode.id), w2));
   assert(listEdgesUpwardT0(nodeLabelB.get(f.id), f));
   assert(listEdgesUpwardT0(nodeLabelB.get(jl.id), jl));
