@@ -20,7 +20,20 @@
 #include <tulip/StringAlgorithm.h>
 #include <tulip/StringProperty.h>
 
-tlp::StringAlgorithm::StringAlgorithm (const tlp::PropertyContext & context):tlp::PropertyAlgorithm(context) {
-  stringResult = (tlp::StringProperty *)context.propertyProxy;
+static const char * paramHelp[] = {
+  HTML_HELP_OPEN() \
+  HTML_HELP_DEF( "type", "StringProperty" ) \
+  HTML_HELP_DEF( "default", "\"viewLabel\"" ) \
+  HTML_HELP_BODY() \
+  "This parameter indicates the property to compute ." \
+  HTML_HELP_CLOSE(),
+};
+
+tlp::StringAlgorithm::StringAlgorithm (const tlp::AlgorithmContext & context):tlp::Algorithm(context), stringResult(NULL) {
+  addOutParameter<tlp::StringProperty>("result", paramHelp[0],
+                                       "viewLabel");
+
+  if (dataSet != NULL)
+    dataSet->get("result", stringResult);
 }
 
