@@ -29,9 +29,10 @@ tlp::DataSet setOrientationParameters(int orientation);
 void addOrthogonalParameters(tlp::LayoutAlgorithm* pLayout);
 void addSpacingParameters(tlp::LayoutAlgorithm* pLayout);
 void getSpacingParameters(tlp::DataSet* dataSet, float& nodeSpacing, float& layerSpacing);
-void addNodeSizePropertyParameter(tlp::LayoutAlgorithm* pLayout);
+void addNodeSizePropertyParameter(tlp::LayoutAlgorithm* pLayout,
+                                  bool inout = false);
 bool getNodeSizePropertyParameter(tlp::DataSet* dataSet, tlp::SizeProperty *&sizes);
-	
+
 orientationType getMask(tlp::DataSet* dataSet);
 bool hasOrthogonalEdge(tlp::DataSet* dataSet);
 
