@@ -18,7 +18,7 @@
  */
 #include <string>
 #include <cassert>
-#include <math.h> 
+#include <math.h>
 #include <stack>
 #include <tulip/SortIterator.h>
 #include "HierarchicalGraph.h"
@@ -34,15 +34,15 @@ static const int NB_UPDOWN_SWEEP = 4;
 
 //================================================================================
 namespace {
-  const char * paramHelp[] = {
-    //Orientation
-    HTML_HELP_OPEN()				 \
-    HTML_HELP_DEF( "type", "String Collection" ) \
-    HTML_HELP_DEF( "default", "horizontal" )	 \
-    HTML_HELP_BODY() \
-    "This parameter enables to choose the orientation of the drawing"	\
-    HTML_HELP_CLOSE()
-  };
+const char * paramHelp[] = {
+  //Orientation
+  HTML_HELP_OPEN()         \
+  HTML_HELP_DEF( "type", "String Collection" ) \
+  HTML_HELP_DEF( "default", "horizontal" )   \
+  HTML_HELP_BODY() \
+  "This parameter enables to choose the orientation of the drawing" \
+  HTML_HELP_CLOSE()
+};
 }
 //================================================================================
 #define ORIENTATION "horizontal;vertical;"
@@ -66,18 +66,22 @@ public:
   }
 };
 //================================================================================
-void HierarchicalGraph::buildGrid(tlp::Graph *sg){
+void HierarchicalGraph::buildGrid(tlp::Graph *sg) {
   //  cerr << __PRETTY_FUNCTION__  << endl;
   string erreurMsg;
   DoubleProperty dagLevel(sg);
+
   if(!sg->computeProperty("Dag Level", &dagLevel,erreurMsg)) {
     cerr << "[ERROR] : " << erreurMsg << __PRETTY_FUNCTION__ << endl;
     return;
   }
+
   node n;
   forEach(n, sg->getNodes()) {
     unsigned int level=(unsigned int)dagLevel.getNodeValue(n);
+
     while (level>=grid.size()) grid.push_back(vector<node>());
+
     embedding->setNodeValue(n, grid[level].size());
     grid[level].push_back(n);
   }
@@ -94,16 +98,18 @@ unsigned int HierarchicalGraph::degree(tlp::Graph *sg, tlp::node n,bool sense) {
 //If sense==true fixed_layer is freeLayer+1 else freeLayer-1
 //Compute barycenter heuristique
 
-void HierarchicalGraph::twoLayerCrossReduction(tlp::Graph *sg,unsigned int freeLayer,bool){
+void HierarchicalGraph::twoLayerCrossReduction(tlp::Graph *sg,unsigned int freeLayer,bool) {
   vector<node>::const_iterator it;
+
   for (it = grid[freeLayer].begin(); it!=grid[freeLayer].end(); ++it) {
     node n = *it;
     double sum = embedding->getNodeValue(n);
     node it;
     forEach(it, sg->getInOutNodes(n))
-      sum += embedding->getNodeValue(it);
+    sum += embedding->getNodeValue(it);
     embedding->setNodeValue(n, sum / (double(sg->deg(n)) + 1.0 ) );
   }
+
   /*
   stable_sort(grid[freeLayer].begin(), grid[freeLayer].end(), lessNode);
   unsigned int j = 0;
@@ -122,13 +128,13 @@ void HierarchicalGraph::twoLayerCrossReduction(Graph *sg,unsigned int freeLayer,
     if (degree(sg,  n, sense)>0) {
       double sum = embedding->getNodeValue(n);
       Iterator<node>*itN;
-      if (sense) 
-	itN=sg->getOutNodes(n);
+      if (sense)
+  itN=sg->getOutNodes(n);
       else
-	itN=sg->getInNodes(n);
+  itN=sg->getInNodes(n);
       while(itN->hasNext()) {
-	node itn=itN->next();
-	sum += embedding->getNodeValue(itn);
+  node itn=itN->next();
+  sum += embedding->getNodeValue(itn);
       } delete itN;
       embedding->setNodeValue(n,sum/((double)degree(sg,n,sense) + 1.0));
     }
@@ -150,6 +156,7 @@ void HierarchicalGraph::twoLayerCrossReduction(Graph *sg,unsigned int freeLayer,
 //Set initial position using a DFS
 void HierarchicalGraph::initCross(tlp::Graph *sg, tlp::node n, tlp::MutableContainer<bool> &visited, int id) {
   if (visited.get(n.id)) return;
+
   visited.set(n.id, true);
   embedding->setNodeValue(n, id);
   node it;
@@ -159,12 +166,12 @@ void HierarchicalGraph::initCross(tlp::Graph *sg, tlp::node n, tlp::MutableConta
 }
 //================================================================================
 // Do layer by layer sweep to reduce crossings in K-Layer graph
-void HierarchicalGraph::crossReduction(tlp::Graph *sg){
+void HierarchicalGraph::crossReduction(tlp::Graph *sg) {
 
   node tmp = sg->addNode();
   embedding->setNodeValue(tmp, 0);
   node it;
-  forEach(it, sg->getNodes()){
+  forEach(it, sg->getNodes()) {
     if (sg->outdeg(it) == 0)
       sg->addEdge(it, tmp);
   }
@@ -173,14 +180,14 @@ void HierarchicalGraph::crossReduction(tlp::Graph *sg){
   //  cerr << __PRETTY_FUNCTION__  << endl;
   MutableContainer<bool> visited;
   visited.setAll(false);
-  node root;
-  tlp::getSource(sg,root);
+  node root = sg->getSource();
   initCross(sg, root, visited, 1);
 
   for (unsigned int a=0; a<grid.size(); ++a) {
     vector<node>::const_iterator it;
     unsigned int j=0;
     stable_sort(grid[a].begin(), grid[a].end(), lessNode);
+
     for (it=grid[a].begin(); it!=grid[a].end(); ++it) {
       embedding->setNodeValue(*it,j);
       j++;
@@ -188,12 +195,14 @@ void HierarchicalGraph::crossReduction(tlp::Graph *sg){
   }
 
   unsigned int maxDepth = grid.size();
+
   //Iterations of the sweeping
   for (int a=0; a<NB_UPDOWN_SWEEP; ++a) {
     //Up sweeping
     for (int i = maxDepth-1; i>=0; --i) {
       twoLayerCrossReduction(graph,i,true);
     }
+
     //Down sweeping
     for (unsigned int i = 0; i<maxDepth; ++i) {
       twoLayerCrossReduction(graph,i,false);
@@ -204,11 +213,13 @@ void HierarchicalGraph::crossReduction(tlp::Graph *sg){
     vector<node>::const_iterator it;
     unsigned int j=0;
     stable_sort(grid[a].begin(), grid[a].end(), lessNode);
+
     for (it=grid[a].begin(); it!=grid[a].end(); ++it) {
       embedding->setNodeValue(*it,j);
       j++;
     }
   }
+
   sg->delNode(tmp, true);
   //  cerr << __PRETTY_FUNCTION__  << endl;
 }
@@ -224,14 +235,15 @@ void HierarchicalGraph::DagLevelSpanningTree(tlp::Graph* sg, tlp::DoubleProperty
     if (sg->indeg(n) > 1) {
       vector<edge> tmpVect;
       edge e;
-      forEach(e, sg->getInEdges(n)) 
-	tmpVect.push_back(e);
+      forEach(e, sg->getInEdges(n))
+      tmpVect.push_back(e);
       sort(tmpVect.begin(), tmpVect.end(), tmpL);
       int toKeep = tmpVect.size()/2;
       vector<edge>::const_iterator it;
+
       for (it=tmpVect.begin(); it!=tmpVect.end(); ++it, --toKeep) {
-	if (toKeep!=0) 
-	  sg->delEdge(*it);
+        if (toKeep!=0)
+          sg->delEdge(*it);
       }
     }
   }
@@ -239,32 +251,38 @@ void HierarchicalGraph::DagLevelSpanningTree(tlp::Graph* sg, tlp::DoubleProperty
   //  cerr << __PRETTY_FUNCTION__  << endl;
 }
 //==============================================================================================================
-void HierarchicalGraph::computeEdgeBends(const tlp::Graph *mySGraph, tlp::LayoutProperty &tmpLayout, 
-					 const TLP_HASH_MAP<tlp::edge,tlp::edge> &replacedEdges, const std::vector<tlp::edge> &reversedEdges) {
+void HierarchicalGraph::computeEdgeBends(const tlp::Graph *mySGraph, tlp::LayoutProperty &tmpLayout,
+    const TLP_HASH_MAP<tlp::edge,tlp::edge> &replacedEdges, const std::vector<tlp::edge> &reversedEdges) {
   //  cerr << "we compute bends on splitted edges" << endl;
   MutableContainer<bool> isReversed;
   isReversed.setAll(false);
+
   for (vector<edge>::const_iterator it = reversedEdges.begin(); it != reversedEdges.end(); ++it)
     isReversed.set((*it).id, true);
-  
+
   for (TLP_HASH_MAP<edge,edge>::const_iterator it = replacedEdges.begin(); it!=replacedEdges.end(); ++it) {
     edge toUpdate = (*it).first;
     edge start = (*it).second;
     edge end = start;
     Coord p1,p2;
+
     //we take the first and last point of the replaced edges
     while (graph->target(end) != graph->target(toUpdate)) {
-       Iterator<edge> *itE = mySGraph->getOutEdges(graph->target(end));
+      Iterator<edge> *itE = mySGraph->getOutEdges(graph->target(end));
+
       if (!itE->hasNext()) {
-	delete itE;
-	break;
+        delete itE;
+        break;
       }
+
       end = itE->next();
       delete itE;
     }
+
     node firstN = graph->target(start);
     node endN = graph->source(end);
     LineType::RealType edgeLine;
+
     if (isReversed.get(toUpdate.id)) {
       p1 = tmpLayout.getNodeValue(endN);
       p2 = tmpLayout.getNodeValue(firstN);
@@ -273,12 +291,14 @@ void HierarchicalGraph::computeEdgeBends(const tlp::Graph *mySGraph, tlp::Layout
       p1 = tmpLayout.getNodeValue(firstN);
       p2 = tmpLayout.getNodeValue(endN);
     }
-    if (p1==p2) 
-      edgeLine.push_back(p1); 
+
+    if (p1==p2)
+      edgeLine.push_back(p1);
     else {
-      edgeLine.push_back(p1); 
+      edgeLine.push_back(p1);
       edgeLine.push_back(p2);
     }
+
     layoutResult->setEdgeValue(toUpdate,edgeLine);
   }
 }
@@ -293,46 +313,53 @@ void HierarchicalGraph::computeSelfLoops(tlp::Graph *mySGraph, tlp::LayoutProper
     const LineType::RealType &edge2 = tmpLayout.getEdgeValue(tmp.e2);
     const LineType::RealType &edge3 = tmpLayout.getEdgeValue(tmp.e3);
     LineType::RealType::const_iterator it;
+
     for (it = edge1.begin(); it!=edge1.end(); ++it)
       tmpLCoord.push_back(*it);
+
     tmpLCoord.push_back(tmpLayout.getNodeValue(tmp.n1));
+
     for (it = edge2.begin(); it!=edge2.end(); ++it)
       tmpLCoord.push_back(*it);
+
     tmpLCoord.push_back(tmpLayout.getNodeValue(tmp.n2));
+
     for (it = edge3.begin(); it!=edge3.end(); ++it)
       tmpLCoord.push_back(*it);
+
     layoutResult->setEdgeValue(tmp.old,tmpLCoord);
     mySGraph->delNode(tmp.n1, true);
     mySGraph->delNode(tmp.n2, true);
-  }  
+  }
+
   //  cerr << "we clean every added nodes and edges" << endl;
 }
 
 
 namespace {
-  //============================================================================
-  void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
-    nodeVisited.set(n.id, true);
-    vec.push_back(n);
-    node dest;
-    forEach(dest, sg->getInOutNodes(n)) {
-      if (!nodeVisited.get(dest.id)) {
-	dfsRecCall(sg, vec, nodeVisited, dest);
-      }
+//============================================================================
+void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
+  nodeVisited.set(n.id, true);
+  vec.push_back(n);
+  node dest;
+  forEach(dest, sg->getInOutNodes(n)) {
+    if (!nodeVisited.get(dest.id)) {
+      dfsRecCall(sg, vec, nodeVisited, dest);
     }
   }
-  //============================================================================
-  void buildDfsOrdering(Graph *sg, vector<node> &vec) {
-    MutableContainer<bool> nodeVisited;
-    nodeVisited.setAll(false);
-    node n;
-    forEach(n, sg->getNodes()) {
-      if (!nodeVisited.get(n.id)) {
-	dfsRecCall(sg, vec, nodeVisited, n);
-      }
+}
+//============================================================================
+void buildDfsOrdering(Graph *sg, vector<node> &vec) {
+  MutableContainer<bool> nodeVisited;
+  nodeVisited.setAll(false);
+  node n;
+  forEach(n, sg->getNodes()) {
+    if (!nodeVisited.get(n.id)) {
+      dfsRecCall(sg, vec, nodeVisited, n);
     }
   }
 }
+}
 //=======================================================================
 bool HierarchicalGraph::run() {
   //make acyclic
@@ -340,7 +367,7 @@ bool HierarchicalGraph::run() {
   vector<node> order;
   buildDfsOrdering(graph, order);
   MutableContainer<int> orderid;
-  for(unsigned int i=0; i< order.size(); ++i) 
+  for(unsigned int i=0; i< order.size(); ++i)
     orderid.set(order[i].id, i);
   edge e;
   forEach(e, graph->getEdges()) {
@@ -349,30 +376,38 @@ bool HierarchicalGraph::run() {
     if(orderid.get(src.id) > orderid.get(tgt.id))
       graph->reverse(e);
   }
-  */    
+  */
   //=======================================================================
-  nodeSize = graph->getProperty<SizeProperty>("viewSize");
   orientation = "horizontal";
   spacing = 64.0;
   nodeSpacing = 18;
+  SizeProperty* nodeSize = NULL;
+
   if (dataSet!=0) {
     getNodeSizePropertyParameter(dataSet, nodeSize);
     getSpacingParameters(dataSet, nodeSpacing, spacing);
     StringCollection tmp;
+
     if (dataSet->get("orientation", tmp)) {
       orientation = tmp.getCurrentString();
     }
   }
-  // ensure size updates will be kept after a pop
-  preservePropertyUpdates(nodeSize);
+
+  if (nodeSize == NULL)
+    nodeSize = graph->getProperty<SizeProperty>("viewSize");
+
   //=========================================================
-  //rotate size if necessary
+  // use a temporary rotated size if necessary
   if (orientation == "horizontal") {
+    SizeProperty* tmpSize = new SizeProperty(graph);
+
+    tmpSize->copy(nodeSize);
     node n;
     forEach(n, graph->getNodes()) {
-      const Size& tmp = nodeSize->getNodeValue(n);
-      nodeSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
+      const Size& tmp = tmpSize->getNodeValue(n);
+      tmpSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
     }
+    nodeSize = tmpSize;
   }
 
   // push a temporary graph state (not redoable)
@@ -380,7 +415,7 @@ bool HierarchicalGraph::run() {
 
   //========================================================================
   // Build a clone of this graph
-  Graph *mySGraph = tlp::newCloneSubGraph(graph,"tmp clone");
+  Graph *mySGraph = graph->addCloneSubGraph("tmp clone");
 
   //if the graph is not acyclic we reverse edges to make it acyclic
   vector<tlp::SelfLoops> listSelfLoops;
@@ -389,12 +424,13 @@ bool HierarchicalGraph::run() {
 
   //========================================================================
   //We add a node and edges to force the dag to have only one source.
-  node startNode = tlp::makeSimpleSource(mySGraph);
-  
+  tlp::makeSimpleSource(mySGraph);
+
   //========================================================================
   list<node> properAddedNodes;
   TLP_HASH_MAP<edge,edge> replacedEdges;
   IntegerProperty *edgeLength = 0;
+
   if (!TreeTest::isTree(mySGraph)) {
     //We transform the dag in a proper dag
     edgeLength = new IntegerProperty(mySGraph);
@@ -410,94 +446,98 @@ bool HierarchicalGraph::run() {
       vector<edge> order;
       edge e;
       forEach(e, new SortTargetEdgeIterator(mySGraph->getOutEdges(n),mySGraph, embedding)) {
-	order.push_back(e);
+        order.push_back(e);
       }
       mySGraph->setEdgeOrder(n, order);
-    }  
+    }
     //We extract a spanning tree from the proper dag.
     DagLevelSpanningTree(mySGraph, &embed);
-  } else {
+  }
+  else {
     DoubleProperty embed(mySGraph);
     embedding = &embed;
     buildGrid(mySGraph);
   }
-  
+
   //We draw the tree using a tree drawing algorithm
+#ifndef NDEBUG
   bool resultBool;
+#endif
   string erreurMsg;
   LayoutProperty tmpLayout(graph);
   DataSet tmp;
   tmp.set("node size", nodeSize);
   tmp.set("layer spacing", spacing);
   tmp.set("node spacing", nodeSpacing);
+
   if (edgeLength!=0)
     tmp.set("edge length", edgeLength);
+
   tmp.set("orthogonal", true);
   StringCollection tmpS("vertical;horizontal;");
   tmpS.setCurrent("vertical");
   tmp.set("orientation", tmpS);
-  resultBool = mySGraph->computeProperty("Hierarchical Tree (R-T Extended)", &tmpLayout, erreurMsg, 0, &tmp);
+#ifndef NDEBUG
+  resultBool =
+#endif
+    mySGraph->computeProperty("Hierarchical Tree (R-T Extended)", &tmpLayout, erreurMsg, 0, &tmp);
 
   if (edgeLength)
     delete edgeLength;
 
   assert(resultBool);
-  
-  
+
+
   node n;
   forEach(n, graph->getNodes()) {
     layoutResult->setNodeValue(n, tmpLayout.getNodeValue(n));
   }
 
-  //  computeEdgeBends(mySGraph, tmpLayout, replacedEdges, reversedEdges);
-  //  computeSelfLoops(mySGraph, tmpLayout, listSelfLoops);
   computeEdgeBends(graph, tmpLayout, replacedEdges, reversedEdges);
   computeSelfLoops(graph, tmpLayout, listSelfLoops);
-  /*
-  for (vector<edge>::const_iterator it=reversedEdges.begin(); it!=reversedEdges.end(); ++it) {
-    graph->reverse(*it);
-  }
-  mySGraph->delAllNode(startNode);
-  while(!properAddedNodes.empty()) {
-    mySGraph->delAllNode(properAddedNodes.back());
-    properAddedNodes.pop_back();
-  }
-  graph->delSubGraph(mySGraph);
-  */
 
-  // forget last temporary graph state 
+  // forget last temporary graph state
   graph->pop();
 
-  //post processing 
+  //post processing
   //Prevent edge node overlaping
   std::vector< float > levelMaxSize(grid.size());
   MutableContainer<int> nodeLevel;
 
-  for (unsigned int i = 0; i<grid.size();++i) {
+  for (unsigned int i = 0; i<grid.size(); ++i) {
     levelMaxSize[i] = 0;
+
     for (unsigned int j= 0; j < grid[i].size(); ++ j) {
       node n = grid[i][j];
+
       if(graph->isElement(n)) {
-	nodeLevel.set(n.id, i);
-	const Size& tmp = nodeSize->getNodeValue(n);
-	levelMaxSize[i] = std::max(levelMaxSize[i], tmp[1]);
+        nodeLevel.set(n.id, i);
+        const Size& tmp = nodeSize->getNodeValue(n);
+        levelMaxSize[i] = std::max(levelMaxSize[i], tmp[1]);
       }
     }
   }
+
   edge e;
   forEach(e, graph->getEdges()) {
-    node src = graph->source(e);
-    node tgt = graph->target(e);
+    std::pair<node, node> eEnds(graph->ends(e));
+    node src = eEnds.first;
+    node tgt = eEnds.second;
+
     if (src == tgt) {
       continue;
     }
+
     float rev = -1.0;
+
     if (nodeLevel.get(src.id)>nodeLevel.get(tgt.id)) {
       rev = 1.0;
     }
+
     Coord srcPos = layoutResult->getNodeValue(src);
     Coord tgtPos = layoutResult->getNodeValue(tgt);
     vector<Coord> old = layoutResult->getEdgeValue(e);
+
     if (old.empty()) {
       vector<Coord> pos(2);
       srcPos[1] += rev*(levelMaxSize[nodeLevel.get(src.id)]/2.f + spacing/4.f);
@@ -515,10 +555,10 @@ bool HierarchicalGraph::run() {
       src2Pos[1] = srcPos[1] + rev*spacing/2.f;
       tgt2Pos[1] = tgtPos[1] - rev*spacing/2.f;
       /*
-	Coord src2Pos = old.front();
-	Coord tgt2Pos = old.back();
-	src2Pos[1] += rev*(levelMaxSize[nodeLevel.get(src.id) + 1]/2.0 + spacing/4.);
-	tgt2Pos[1] -= rev*(levelMaxSize[nodeLevel.get(tgt.id) - 1]/2.0 + spacing/4.);
+        Coord src2Pos = old.front();
+        Coord tgt2Pos = old.back();
+        src2Pos[1] += rev*(levelMaxSize[nodeLevel.get(src.id) + 1]/2.0 + spacing/4.);
+        tgt2Pos[1] -= rev*(levelMaxSize[nodeLevel.get(tgt.id) - 1]/2.0 + spacing/4.);
       */
       pos[0] = srcPos;
       pos[1] = src2Pos;
@@ -527,7 +567,7 @@ bool HierarchicalGraph::run() {
       layoutResult->setEdgeValue(e, pos);
     }
   }
-  
+
   //post processing align nodes
   forEach(n, graph->getNodes()) {
     Coord tmp = layoutResult->getNodeValue(n);
@@ -536,12 +576,12 @@ bool HierarchicalGraph::run() {
     layoutResult->setNodeValue(n, tmp);
   }
 
-  //rotate layout and size
+  //rotate layout
   if (orientation == "horizontal") {
+    // delete the temporary allocated SizeProperty (see above)
+    delete nodeSize;
     node n;
     forEach(n, graph->getNodes()) {
-      const Size&  tmp = nodeSize->getNodeValue(n);
-      nodeSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
       const Coord& tmpC = layoutResult->getNodeValue(n);
       layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
@@ -550,9 +590,11 @@ bool HierarchicalGraph::run() {
       LineType::RealType tmp = layoutResult->getEdgeValue(e);
       LineType::RealType tmp2;
       LineType::RealType::iterator it;
+
       for (it = tmp.begin(); it!= tmp.end(); ++it) {
-	tmp2.push_back(Coord(-(*it)[1], (*it)[0], (*it)[2]));
+        tmp2.push_back(Coord(-(*it)[1], (*it)[0], (*it)[2]));
       }
+
       layoutResult->setEdgeValue(e, tmp2);
     }
   }
