@@ -20,21 +20,23 @@
 #define NUMBER_H
 
 /**
- *This class enables the comparison of floats or the initialization of float 
+ *This class enables the comparison of floats or the initialization of float
  *to infinity.
  */
-class Number{
- public:
- 
+class Number {
+public:
+
   float value;/**< Contain the value of the number. */
- 
+
   static float infini;/**< contain our value of infinity. */
 
- public:
+public:
   /**
    *The constructor initializes the field value to the float f.
    */
-  Number(float f) {value=f;};
+  Number(float f) {
+    value=f;
+  };
 
   /**
    *Overload of the operator >.
@@ -43,6 +45,6 @@ class Number{
 };
 
 
-  
+
 
 #endif
