@@ -35,12 +35,11 @@
  *
  *  \author David Auber University Bordeaux I France, Email : auber@tulip-software.com
  */
-class Random:public tlp::LayoutAlgorithm
-{ 
+class Random:public tlp::LayoutAlgorithm {
 public:
   Random(const tlp::PropertyContext& context);
   ~Random();
-  
+
   bool run();
   bool check(std::string& erreurMsg);
 };
