@@ -20,19 +20,20 @@
 
 using namespace tlp;
 
-DOUBLEPLUGINOFGROUP(RandomMetric,"Random","David Auber","04/10/2001","Alpha","1.0","Misc")
+
+DOUBLEPLUGINOFGROUP(RandomMetric,"Random metric","David Auber","04/10/2001","Alpha","1.1","Misc")
 
 //===========================================
-RandomMetric::RandomMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) 
+RandomMetric::RandomMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context)
 {}
 //===========================================
 bool RandomMetric::run() {
   node n;
   forEach(n, graph->getNodes())
-    doubleResult->setNodeValue(n, (double)rand() / double(RAND_MAX));
+  doubleResult->setNodeValue(n, (double)rand() / double(RAND_MAX));
   edge e;
   forEach(e, graph->getEdges())
-    doubleResult->setEdgeValue(e, (double)rand() / double(RAND_MAX));
+  doubleResult->setEdgeValue(e, (double)rand() / double(RAND_MAX));
   return true;
 }
 //===========================================
